verticalitytools.get_vertical_moment_at_prolated_offset_in_expr
===============================================================

.. autofunction:: abjad.tools.verticalitytools.get_vertical_moment_at_prolated_offset_in_expr.get_vertical_moment_at_prolated_offset_in_expr
